@@ -20,7 +20,8 @@ __banner__ = r""" (
 
 
 
-""" # __banner__
+"""  # __banner__
+
 
 class TestFORTH:
 
@@ -48,8 +49,7 @@ class TestFORTH:
         """
         e = FORTH.Engine(self.test_0002.__doc__, **self.options)
         assert e.root.stack == []
-        assert e.root.memory == {456 : 123}
-
+        assert e.root.memory == {456: 123}
 
     def test_0003(self):
         r"""
@@ -58,8 +58,7 @@ class TestFORTH:
         """
         e = FORTH.Engine(self.test_0003.__doc__, **self.options)
         assert e.root.stack == []
-        assert e.root.memory == {"FOO_1" : 123, "FOO_2": "Baz"}
-
+        assert e.root.memory == {"FOO_1": 123, "FOO_2": "Baz"}
 
     def test_1000(self):
         r"""
@@ -120,7 +119,6 @@ T{ 1S 1S XOR -> 0S }T
 
         """
 
-
     def test_LSHIFT_RSHIFT(self):
         e = FORTH.Engine(self.LSHIFT_RSHIFT, **self.options)
         assert e.root.test["f"] == 0
@@ -168,7 +166,6 @@ T{ MSB 1 RSHIFT 2* -> MSB }T
 
         """
 
-
     def test_COMPARISONS(self):
         e = FORTH.Engine(self.COMPARISONS, **self.options)
         assert e.root.test["f"] == 0
@@ -252,7 +249,6 @@ T{ 1 -1 MAX -> 1 }T
 
         """
 
-
     def test_STACK_OPS(self):
         e = FORTH.Engine(self.STACK_OPS, **self.options)
         assert e.root.test["f"] == 0
@@ -278,7 +274,6 @@ T{ 1 2 SWAP -> 2 1 }T
 
     """
 
-
     def test_RETURN_STACK(self):
         e = FORTH.Engine(self.RETURN_STACK, **self.options)
         assert e.root.test["f"] == 0
@@ -503,7 +498,6 @@ T{ 123 456 A-ADDR CELL+ 2!  A-ADDR CELL+ 2@ -> 123 456 }T
 
     """
 
-
     def test_COMPILE(self):
         e = FORTH.Engine(self.COMPILE, **self.options)
         assert e.root.test["f"] == 0
@@ -739,7 +733,6 @@ T{ GS4 123 456
 
     """
 
-
     def test_FILL_MOVE(self):
         e = FORTH.Engine(self.FILL_MOVE, **self.options)
         assert e.root.test["f"] == 0
@@ -783,6 +776,7 @@ T{ SEEBUF -> 12 34 34 }T
 
     """
 
+
 from cubed4th import FORTH
 
 try:
@@ -790,8 +784,8 @@ try:
 except ImportError:  # Graceful fallback if IceCream isn't installed.
     ic = lambda *a: None if not a else (a[0] if len(a) == 1 else a)  # noqa
 
-builtins = __import__('builtins')
-setattr(builtins, 'ic', ic)
+builtins = __import__("builtins")
+setattr(builtins, "ic", ic)
 
 #
 # \ From: John Hayes S1I
@@ -808,4 +802,3 @@ setattr(builtins, 'ic', ic)
 # \ I HAVEN'T FIGURED OUT HOW TO TEST KEY, QUIT, ABORT, OR ABORT"...
 # \ I ALSO HAVEN'T THOUGHT OF A WAY TO TEST ENVIRONMENT?...
 #
-
